WidgetProvider class
- Annotations
-
- @Deprecated("Resolve widgets using WidgetResolver instead.")
Constructors
- WidgetProvider(DependencyContainer _container, Initializer _initializer, WidgetResolver _widgetResolver)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
canResolveWidget<
T extends Widget> () → bool -
getInitializedRawWidget<
T extends Widget> ({Key? key, dynamic args}) → Future< T> -
getInitializedWidget<
T extends Widget> ({Key? key, dynamic args}) → Future< T> -
getRawWidget<
T extends Widget> ({Key? key, dynamic args}) → T -
getWidget<
T extends Widget> ({Key? key, dynamic args}) → T -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveWidget<
T extends Widget> ({Key? key, dynamic args}) → Widget -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited