WidgetResolver class
Constructors
- WidgetResolver(DependencyContainer _container, Initializer _initializer)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
canResolve<
T extends Widget> () → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve<
T extends Widget> ({Key? key, dynamic args}) → Widget -
resolveExactType<
T extends Widget> ({Key? key, dynamic args}) → T -
resolveExactTypeInitialized<
T extends Widget> ({Key? key, dynamic args}) → Future< T> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
customDeferredWidgetFactory
↔ Widget Function(Future<
Widget> )? -
getter/setter pair